@@ -19,9 +19,8 @@ from kodexa.connectors.connectors import get_caller_dir, FolderConnector
 from kodexa.model import Document, DocumentStore
 from kodexa.pipeline import PipelineContext, Pipeline, PipelineStatistics
 from kodexa.stores import RemoteDocumentStore
-from kodexa.stores import TableDataStore
-from kodexa.stores.stores import LocalDocumentStore
-from kodexa.taxonomy.taxonomy import Taxonomy
+from kodexa.stores import TableDataStore, RemoteModelStore, LocalDocumentStore, LocalModelStore
+from kodexa.taxonomy import Taxonomy
 from kodexa.workflow.workflow import Workflow
 
 logger = logging.getLogger('kodexa.platform')
@@ -300,7 +299,14 @@ class KodexaPlatform:
             metadata_object.description = 'A document store' if metadata_object.description is None else metadata_object.description
 
             metadata_object.type = 'store'
-            metadata_object.contentType = 'DOCUMENT'
+            metadata_object.storeType = 'DOCUMENT'
+        elif isinstance(kodexa_object, LocalModelStore) or isinstance(kodexa_object, RemoteModelStore):
+            object_url = 'stores'
+            metadata_object.name = 'New Store' if metadata_object.name is None else metadata_object.name
+            metadata_object.description = 'A model store' if metadata_object.description is None else metadata_object.description
+
+            metadata_object.type = 'store'
+            metadata_object.storeType = 'MODEL'
         elif isinstance(kodexa_object, Workflow):
             metadata_object.name = 'New Workflow' if metadata_object.name is None else metadata_object.name
             metadata_object.description = 'A new workflow' if metadata_object.description is None else metadata_object.description
@@ -309,6 +315,7 @@ class KodexaPlatform:
             metadata_object.pipelines = list(map(lambda x: x.__dict__, kodexa_object.pipelines))
             metadata_object.stores = list(map(lambda x: x.__dict__, kodexa_object.stores))
             metadata_object.connectors = list(map(lambda x: x.__dict__, kodexa_object.connectors))
+            metadata_object.schedules = list(map(lambda x: x.__dict__, kodexa_object.schedules))
             metadata_object.accessToken = kodexa_object.access_token
         elif isinstance(kodexa_object, Taxonomy):
             metadata_object.name = 'New Taxonomy' if metadata_object.name is None else metadata_object.name
@@ -351,7 +358,7 @@ class KodexaPlatform:
             else:
                 logger.error(response.text)
                 raise Exception("Unable to deploy")
-        else:
+        elif response.status_code == 200:
             logger.info(f"{ref} already exists")
             if force_replace:
                 logger.info(f"Replacing {ref}")
@@ -367,6 +374,9 @@ class KodexaPlatform:
             else:
                 logger.warning("Not updating")
                 return
+        else:
+            logger.error("Unable to deploy")
+            logger.error(response.content)
 
     @staticmethod
     def list_objects(organization_slug, object_type):
@@ -531,7 +541,7 @@ class RemoteSession:
 
         self.cloud_session = Dict(json.loads(r.text))
 
-    def execution_action(self, document, options, attach_source):
+    def execution_action(self, document, options, attach_source, context):
         files = {}
         if attach_source:
             logger.debug("Attaching source to call")
@@ -540,7 +550,8 @@ class RemoteSession:
         else:
             files["document"] = document.to_msgpack()
 
-        data = {"options": json.dumps(options), "document_metadata_json": json.dumps(document.metadata)}
+        data = {"options": json.dumps(options), "document_metadata_json": json.dumps(document.metadata),
+                "context": json.dumps(context.context)}
 
         logger.info(f"Executing session {self.cloud_session.id}")
         r = requests.post(f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/execute",
@@ -594,17 +605,19 @@ class RemoteSession:
 
             logger.debug(execution)
 
-            raise Exception("Processing has failed")
+            raise Exception(f"Processing has failed\nDetails: {step.exceptionDetails.help}")
 
         return execution
 
     def get_output_document(self, execution):
         if execution.outputId:
+            logger.info("Downloading output document [{execution.outputId}]")
             doc = requests.get(
                 f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/executions/{execution.id}/objects/{execution.outputId}",
                 headers={"x-access-token": KodexaPlatform.get_access_token()})
             return Document.from_msgpack(doc.content)
         else:
+            logger.info("No output document")
             return None
 
     def get_store(self, execution, store):
@@ -669,19 +682,20 @@ class RemotePipeline:
 
         for document in self.connector:
             logger.info(f"Processing {document}")
-            execution = cloud_session.execution_action(document, self.parameters, self.attach_source)
+            execution = cloud_session.execution_action(document, self.parameters, self.attach_source, self.context)
             execution = cloud_session.wait_for_execution(execution)
 
+            logger.info("Capturing output")
             result_document = cloud_session.get_output_document(execution)
             self.context.set_output_document(result_document)
             cloud_session.merge_stores(execution, self.context)
 
-            self.context.statistics.processed_document(document)
-
+            self.context.statistics.processed_document(result_document)
+            self.context.context = execution.context
             if self.sink:
                 logger.info(f"Writing to sink {self.sink.get_name()}")
                 try:
-                    self.sink.sink(document)
+                    self.sink.sink(result_document)
                 except:
                     if document:
                         document.exceptions.append({
@@ -696,7 +710,7 @@ class RemotePipeline:
         return self.context
 
     @staticmethod
-    def from_url(slug: str, url, headers=None) -> RemotePipeline:
+    def from_url(slug: str, url, headers=None, *args, **kwargs) -> RemotePipeline:
         """
         Build a new pipeline with the input being a document created from the given URL
 
@@ -705,19 +719,20 @@ class RemotePipeline:
         :param headers: A dictionary of headers
         :return: A new instance of a remote pipeline
         """
-        return RemotePipeline(slug, Document.from_url(url, headers))
+        return RemotePipeline(slug, Document.from_url(url, headers), *args, **kwargs)
 
     @staticmethod
-    def from_file(slug: str, file_path: str) -> RemotePipeline:
+    def from_file(slug: str, file_path: str, unpack: bool = False, *args, **kwargs) -> RemotePipeline:
         """
         Create a new pipeline using a file path as a source
 
         :param slug: The slug for the remote pipeline
         :param file_path: The path to the file
+        :param unpack: Unpack the file as a KDXA
         :return: A new pipeline
         :rtype: Pipeline
         """
-        return RemotePipeline(slug, Document.from_file(file_path))
+        return RemotePipeline(slug, Document.from_file(file_path, unpack), *args, **kwargs)
 
     @staticmethod
     def from_text(slug: str, text: str, *args, **kwargs) -> RemotePipeline:
@@ -729,10 +744,14 @@ class RemotePipeline:
         :return: A new pipeline
         :rtype: RemotePipeline
         """
-        return RemotePipeline(slug, Document.from_text(text))
+
+        # need to update kwargs for attach_source
+        kwargs.setdefault('attach_source', False)
+        return RemotePipeline(slug, Document.from_text(text), *args, **kwargs)
 
     @staticmethod
     def from_folder(slug: str, folder_path: str, filename_filter: str = "*", recursive: bool = False,
+                    unpack: bool = False,
                     relative: bool = False,
                     caller_path: str = get_caller_dir()) -> RemotePipeline:
         """
@@ -744,10 +763,12 @@ class RemotePipeline:
         :param recursive: Should we look recursively in sub-directories (default False)
         :param relative: Is the folder path relative to the caller (default False)
         :param caller_path: The caller path (defaults to trying to work this out from the stack)
+        :param unpack: Unpack the file as a KDXA document
         :return: A new pipeline
         :rtype: RemotePipeline
         """
-        return RemotePipeline(slug, FolderConnector(folder_path, filename_filter, recursive, relative, caller_path))
+        return RemotePipeline(slug, FolderConnector(folder_path, filename_filter, recursive, relative, caller_path,
+                                                    unpack=unpack))
 
     def to_store(self, document_store: DocumentStore, processing_mode: str = "update"):
         """
@@ -763,6 +784,7 @@ class RemotePipeline:
         self.set_sink(DocumentStoreSink(document_store))
         return self
 
+
 class RemoteAction:
     """
     Allows you to interact with an action that has been deployed in the Kodexa platform
@@ -800,10 +822,15 @@ class RemoteAction:
             requires_source = action_metadata['metadata']['requiresSource']
 
         execution = cloud_session.execution_action(document, self.options,
-                                                   self.attach_source if self.attach_source else requires_source)
+                                                   self.attach_source if self.attach_source else requires_source,
+                                                   context)
+
         execution = cloud_session.wait_for_execution(execution)
 
         result_document = cloud_session.get_output_document(execution)
+
+        context.context = execution.context
+
         cloud_session.merge_stores(execution, context)
 
         return result_document if result_document else document
